#ifndef CREATOR_H
#define CREATOR_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <qwidget.h>
#include <qvariant.h>
#include <qmainwindow.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qaction.h>
#include <qmenubar.h>
#include <qpopupmenu.h>
#include <qtoolbar.h>
#include <qpixmap.h>
#include <qspinbox.h>
#include <qcombobox.h>
#include <qtextedit.h>
#include <qimage.h>
#include <qfileinfo.h>
#include <qregexp.h>

#include <klocale.h>
#include <kapplication.h>
#include <kmainwindow.h>
#include <kiconloader.h>
#include <kaboutdialog.h>
#include <klocale.h>
#include <ktextedit.h>
#include <ktempfile.h>
#include <kprocess.h>
#include <kstandarddirs.h>
#include <kstatusbar.h>
#include <kglobalsettings.h>

#include "../src/karamba.h"

#include "ntheme.h"
#include "image.h"
#include "text.h"
#include "bar.h"
#include "graph.h"
#include "group.h"
#include "font.h"
#include "savedlg.h"
#include "click.h"
#include "icone.h"


class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QAction;
class QPopupMenu;
class QTextEdit;


/**
 * @author Bosselut Cyril <bosselut@b1project.com>
 * @version 0.12
 */
class Creator : public KMainWindow //QMainWindow
{
    Q_OBJECT

public:
    Creator( QWidget* parent = 0, const char* name = 0, WFlags fl = WType_TopLevel );
    ~Creator();

    QWidget* centralW;
    KTextEdit* textEdit1;
    QMenuBar* menubar;
    QPopupMenu *fileMenu;
    QPopupMenu *editMenu;
    QPopupMenu *PopupMenu;
    QPopupMenu *helpMenu;
    KToolBar *toolBar;
    KToolBar *editBar;
    KToolBar *Karamba_Toolbar;
    QAction* fileNewAction;
    QAction* fileOpenAction;
    QAction* fileSaveAction;
    QAction* fileSaveAsAction;
    QAction* filePrintAction;
    QAction* fileExitAction;
    QAction* editUndoAction;
    QAction* editRedoAction;
    QAction* editCutAction;
    QAction* editCopyAction;
    QAction* editPasteAction;
    QAction* editFindAction;
    QAction* helpContentsAction;
    QAction* helpIndexAction;
    QAction* helpAboutAction;
    QAction* AboutKDE;
    QAction* Text;
    QAction* Image;
    QAction* Bar;
    QAction* Graph;
    QAction* Theme;
    QAction* Font;
    QAction* Group;
    QAction* Click;
    QAction* Icon;
    QAction* Run;
    QAction* Stop;
    QString fileName;
    QString currentFile;

public slots:
    virtual void fileNew();
    virtual void fileOpen(QString fn = 0);
    virtual void fileSave();
    virtual void fileSaveAs();
    virtual void filePrint();
    virtual void fileExit();
    virtual void editUndo();
    virtual void editRedo();
    virtual void editCut();
    virtual void editCopy();
    virtual void editPaste();
    virtual void editFind();
    virtual void helpIndex();
    virtual void helpContents();
    virtual void helpAbout();
    /**
    * Show the about KDE dialog.
    */
    void aboutKDE();
    virtual void RunTheme();
    virtual void AddImage();
    virtual void AddText();
    virtual void AddBar();
    virtual void AddGraph();
    virtual void AddTheme();
    virtual void AddGroup();
    virtual void AddFont();
    virtual void AddClick();
    virtual void AddIcon();

protected:
    void closeEvent( QCloseEvent* ce );

protected slots:
    virtual void languageChange();

private:
    void initText();
    void addMeter( QString v, bool cur = false);
    KTempFile* fn;
    karamba *k;
    KStatusBar* status;
    int line;
    int row;
    int prevpara;

private slots:
    void setModif( bool m );
    void upCurPos( int para, int pos );
    void stopKaramba();
    void parse();

};

#endif // CREATOR_H
