/*
 * Copyright (C) 2003 Hans Karlsson <karlsson.h@home.se>
 */

#ifndef _KARAMBA_H_
#define _KARAMBA_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <qwidget.h>
#include <qfile.h>
#include <qfileinfo.h>
#include <qtimer.h>
#include <qpixmap.h>
#include <qpainter.h>
#include <qregexp.h>
#include <qlabel.h>
#include <qobjectlist.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qvaluestack.h>
#include <qcursor.h>
#include <qmap.h>
#include <qdatetime.h>

#include <kapplication.h>
#include <kwinmodule.h>
#include <kwin.h>
#include <kfile.h>
#include <kaction.h>
#include <ksharedpixmap.h>
#include <dcopclient.h>
#include <kpopupmenu.h>
#include <kiconloader.h>
#include <kfiledialog.h>
#include <kurl.h>
#include <krun.h>
#include <ksimpleconfig.h>
#include <kaboutapplication.h>
#include <kaboutkde.h>

#include <netwm.h>

#include "karambarootpixmap.h"
#include "bar.h"
#include "textlabel.h"
#include "imagelabel.h"
#include "iconlabel.h"
#include "graph.h"
#include "clickarea.h"
#include "sensorparams.h"
#include "memsensor.h"
#include "datesensor.h"
#include "uptimesensor.h"
#include "memsensor.h"
#include "cpusensor.h"
#include "networksensor.h"
#include "xmmssensor.h"
#include "noatunsensor.h"
#include "programsensor.h"
#include "disksensor.h"
#include "sensorsensor.h"
#include "textfilesensor.h"
#include "karambaconf.h"

class IconLabel;
/**
 * @author Hans Karlsson <karlsson.h@home.se>
 * @author Bosselut Cyril <bosselut@b1project.com>
 * @version 0.22
 */
class karamba :  public QWidget
{
    Q_OBJECT

public:
    karamba(QString fn, bool noquit = false);

    virtual ~karamba();
    bool isRunning;
    bool hidden;
    int themeX;
    int themeY;
    int themeW;
    int themeH;
    QString themeFile;
    QString themePath;

protected:
    void mousePressEvent( QMouseEvent *);
    void mouseReleaseEvent( QMouseEvent *);
    void mouseDoubleClickEvent( QMouseEvent *);
    void mouseMoveEvent( QMouseEvent *);
    void enterEvent ( QEvent *);
    void leaveEvent ( QEvent *);
    void closeEvent ( QCloseEvent *);
    void paintEvent ( QPaintEvent *);

private:
    KWinModule*    kWinModule;
    NETWinInfo* info;
    bool onTop;
    bool fixedPosition;
    bool nq;

    bool parseConfig();
    int getInt( QString, QString & );
    int getInt( QString, QString &, bool & );
    /**
    * get3Int reads an int triplet, e.g. COLOR:0,50,100
    */
    void get3Int(QString w, QString &line, int&, int&, int& );
    void get3Int(QString w, QString &line, int&, int&, int&, bool& );
    QString getString( QString, QString & );
    QString getString( QString, QString &, bool& );
    bool getBoolean( QString, QString & );
    bool getBoolean( QString, QString &, bool& );

    void setSensor( QString &line , Meter* meter);
    void passClick( QMouseEvent* );

    QMap<QString, Sensor*> sensorMap;
    QObjectList *meterList;
    QObjectList *sensorList;
    QObjectList *clickList;
    QObjectList *timeList;
    QObjectList *imageList;
    QPtrList<IconLabel> *iconList;

    QTime lowerTimer;
    QTimer *m_sysTimer;
    /**
    * use only the first occurance of KARAMBA in a config file.
    */
    bool foundKaramba;
    DCOPClient *client;
    QCString appId;
    QPixmap pm;
    QPixmap background;
    QPainter p;
    KarambaRootPixmap *kroot;
    QString hide;
    int Hlimit;
    bool MouseOver;

    QPoint clickPos;
    int clickX;
    int clickY;
    KPopupMenu *kpop;
    KActionCollection *accColl;
    KToggleAction *toggleLocked;
    bool locked;

public slots:
    /**
    * Force sensors update.
    */
    void updateSensors();
    /**
    * Show the about dialog.
    */
    void about();
    /**
    * Show the about KDE dialog.
    */
    void aboutKDE();
    /**
    * Force reloading the theme.
    */
    void reloadConfig();
    /**
    * Start a new Karamba session.
    */
    void startNewKaramba();
    /**
    * Start the theme creator with current theme (kprocess).
    */
    void editConfig();
    /**
    * Start the theme creator (kprocess).
    */
    void LaunchCreator();
    /**
    * Show the Karamba configuration dialog.
    */
    void Config();
    /**
    * Hide or show the Karamba window.
    */
    void toggleHide();
    /**
    * Create karamba pixmap.
    */
    void step();
    /**
    * Update Karamba background.
    */
    void updateBackground(KSharedPixmap*);

private slots:
    void currentDesktopChanged(int);
    void slotToggleLocked();
    void status( bool );

signals:
    /**
    * emit karamba status (eg: running or not).
    */
    void karambaRun( bool );

};

#endif // _KARAMBA_H_
